"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormGroup = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const ItiReactContext_1 = require("../ItiReactContext");
/**
 * Renders a form input and corresponding label.
 *
 * The children of this component can either be a JSX element or a function that
 * maps `id` string to a JSX element (better for accessibility).
 */
function FormGroup({ label, className, loading, optional = false, ...props }) {
    const idRef = (0, react_1.useRef)((0, iti_react_core_1.getGuid)());
    const { renderLoadingIndicator } = (0, react_1.useContext)(ItiReactContext_1.ItiReactContext);
    let labelInner = label;
    if (optional) {
        labelInner = ((0, jsx_runtime_1.jsxs)("span", { children: [label, " ", (0, jsx_runtime_1.jsx)("span", { className: "optional", children: "(optional)" }, void 0)] }, void 0));
    }
    let children;
    if (typeof props.children === 'function') {
        const renderProp = props.children;
        children = renderProp(idRef.current);
    }
    else {
        children = props.children;
    }
    return ((0, jsx_runtime_1.jsxs)("div", { className: `form-group ${className || ''}`, "data-testid": props['data-testid'], children: [label && ((0, jsx_runtime_1.jsxs)("label", { className: "form-label", htmlFor: idRef.current, children: [labelInner, ' ', typeof loading !== 'undefined' &&
                        loading &&
                        renderLoadingIndicator()] }, void 0)), children] }, void 0));
}
exports.FormGroup = FormGroup;
