"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Dialog = exports.ActionDialog = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const Modal_1 = __importDefault(require("react-bootstrap/Modal"));
const SubmitButton_1 = require("../SubmitButton");
const util_1 = require("../../util");
/**
 * A [[`Dialog`]] that has an action button and a cancel button.
 */
function ActionDialog({ actionButtonText, actionButtonClass = 'btn-primary', cancelButtonText = 'Cancel', action, actionInProgress, title, modalClass, onOpen, onClose, children, focusFirst, actionButtonEnabled = true, showFooter = true, onCancel, closeRef: propsCloseRef, }) {
    const internalCloseRef = (0, react_1.useRef)(() => { });
    const closeRef = propsCloseRef !== null && propsCloseRef !== void 0 ? propsCloseRef : internalCloseRef;
    let footer;
    if (showFooter) {
        footer = ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [(0, jsx_runtime_1.jsx)(SubmitButton_1.SubmitButton, { type: "button", onClick: action, className: `btn ${actionButtonClass !== null && actionButtonClass !== void 0 ? actionButtonClass : ''}`, submitting: actionInProgress, enabled: actionButtonEnabled, children: actionButtonText }, void 0), (0, jsx_runtime_1.jsx)("button", { type: "button", className: "btn btn-secondary", onClick: () => {
                        if (actionInProgress)
                            return;
                        if (onCancel)
                            onCancel();
                        closeRef.current();
                    }, children: cancelButtonText }, void 0)] }, void 0));
    }
    return ((0, jsx_runtime_1.jsx)(Dialog, { title: title, closeRef: closeRef, dialogClassName: modalClass, footer: footer, onOpen: onOpen, onClose: onClose, focusFirst: focusFirst, allowDismiss: !actionInProgress, children: children }, void 0));
}
exports.ActionDialog = ActionDialog;
/**
 * Wrapper around the Bootstrap dialog component.
 *
 * - **DO NOT** unmount the dialog except in the `onClose` function. This will cause
 *   the dialog to be abruptly removed without an animation.
 * - Use `closeRef` to close the dialog from the parent component.
 * - The first input element is automatically focused when the dialog opens. This can be
 *   controlled with the `focusFirst` and `focusFirstOptions` props.
 */
function Dialog({ title, onOpen, onClose, footer, children, closeRef, dialogClassName, focusFirst = true, allowDismiss = true, }) {
    const modalRef = (0, react_1.useRef)(null);
    const [show, setShow] = (0, react_1.useState)(true);
    (0, react_1.useEffect)(() => {
        if (!closeRef)
            return;
        closeRef.current = () => setShow(false);
    });
    const onOpenRef = (0, react_1.useRef)(onOpen);
    (0, react_1.useEffect)(() => {
        onOpenRef.current = onOpen;
    });
    const onEntered = (0, react_1.useCallback)(() => {
        if (focusFirst && modalRef.current)
            (0, util_1.focusFirstInput)(modalRef.current.dialog);
        if (onOpenRef.current)
            onOpenRef.current();
    }, [focusFirst]);
    return ((0, jsx_runtime_1.jsxs)(Modal_1.default, { show: show, onHide: () => {
            if (allowDismiss)
                setShow(false);
        }, onEntered: onEntered, onExited: onClose, ref: modalRef, backdrop: "static", dialogClassName: dialogClassName, children: [(0, jsx_runtime_1.jsx)(Modal_1.default.Header, { closeButton: true, children: (0, jsx_runtime_1.jsx)(Modal_1.default.Title, { children: title }, void 0) }, void 0), (0, jsx_runtime_1.jsx)(Modal_1.default.Body, { children: children }, void 0), footer && (0, jsx_runtime_1.jsx)(Modal_1.default.Footer, { children: footer }, void 0)] }, void 0));
}
exports.Dialog = Dialog;
