"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePopoverClickListener = exports.hasAncestor = void 0;
const lodash_1 = require("lodash");
const event_listener_1 = __importDefault(require("@use-it/event-listener"));
/** @internal */
function hasAncestor(target, selector) {
    const parent = target.parentElement;
    if (!parent)
        return false;
    if (parent.matches(selector))
        return true;
    return hasAncestor(parent, selector);
}
exports.hasAncestor = hasAncestor;
/**
 * A hook that detects when the user has clicked outside of a popover,
 * indicating that the popover should be closed.
 */
function usePopoverClickListener({ visible, onOutsideClick, popoverSelector = '.iti-react-popover', }) {
    function onClick(e) {
        if (!visible)
            return;
        if (!e.target)
            return;
        const target = e.target;
        // Hack to prevent clicking a react select option from closing the popover
        if (hasAncestor(target, '[class$="-menu"]'))
            return;
        const inPopover = target.matches(popoverSelector) || hasAncestor(target, popoverSelector);
        if (!inPopover) {
            // To understand why we use defer here, consider what would happen if we
            // did NOT user defer. When the reference element is clicked, onOutsideClick
            // would be called immediately and the popover would be hidden. Then the
            // onClick handler of the reference element would fire, immediately showing
            // the popover again.
            // We used to prevent this using e.stopPropagation(), but stopping
            // propagation causes LinkButton act like a link to # instead of
            // a button.
            (0, lodash_1.defer)(onOutsideClick);
        }
    }
    (0, event_listener_1.default)('click', onClick);
}
exports.usePopoverClickListener = usePopoverClickListener;
