"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileValidators = exports.FileInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../validation");
/**
 * A file upload control that can be made a required field.
 */
function FileInput({ id, accept, enabled, inputAttributes, showValidation, name, ...props }) {
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: props.value,
        onChange: props.onChange,
        defaultValue: props.defaultValue,
        fallbackValue: null,
    });
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: props.onValidChange,
        validators: props.validators,
        validationKey: props.validationKey,
        asyncValidator: props.asyncValidator,
        onAsyncError: props.onAsyncError,
        formLevelValidatorOutput: props.formLevelValidatorOutput,
    });
    const inputRef = (0, react_1.useRef)(null);
    (0, react_1.useEffect)(() => {
        if (!inputRef.current)
            return;
        if (value === null && inputRef.current.value) {
            inputRef.current.value = '';
        }
    }, [value]);
    return ((0, jsx_runtime_1.jsx)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation, children: (0, jsx_runtime_1.jsx)("input", { id: id, ref: inputRef, className: "form-control", type: "file", name: name, accept: accept, onChange: (e) => {
                var _a;
                const files = (_a = e.target) === null || _a === void 0 ? void 0 : _a.files;
                if (files && files[0]) {
                    onChange(files[0]);
                }
                else {
                    onChange(null);
                }
            } }, void 0) }, void 0));
}
exports.FileInput = FileInput;
function required() {
    return (value) => {
        if (!value)
            return iti_react_core_1.Validators.required()('');
        return undefined;
    };
}
/** For use with [[`FileInput`]]. */
exports.FileValidators = { required };
