"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TimeZoneValidators = exports.TimeZoneInput = exports.resolveValue = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const tzdb_1 = require("@vvo/tzdb");
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const select_1 = require("./select");
/* Not including the zone abbreviation (e.g. EST / EDT ). This becomes a huge pain in
 * the ass since the abbreviation depends on the current date. */
const commonTimeZones = [
    {
        ianaTimeZone: 'America/New_York',
        displayName: 'Eastern Time',
    },
    {
        ianaTimeZone: 'America/Chicago',
        displayName: 'Central Time',
    },
    {
        ianaTimeZone: 'America/Denver',
        displayName: 'Mountain Time',
    },
    {
        ianaTimeZone: 'America/Los_Angeles',
        displayName: 'Pacific Time',
    },
];
const usOptions = commonTimeZones.map((o) => ({
    value: o.ianaTimeZone,
    label: o.displayName,
}));
const advancedOptions = (0, tzdb_1.getTimeZones)()
    .map((o) => ({
    value: o.name,
    label: o.rawFormat,
}))
    .filter((o) => !usOptions.find((oo) => o.value === oo.value));
const options = [
    { label: 'US time zones', options: usOptions },
    { label: 'All time zones', options: advancedOptions },
];
const allOptions = [...usOptions, ...advancedOptions];
const optionValueSet = new Set(allOptions.map((o) => o.value));
/**
 * @internal
 *
 * Because tzdb groups time zones, there isn't a SelectOption for every IANA time zone.
 * This function converts the value to a time zone that has an option.
 */
function resolveValue(value, onChange) {
    if (value && !optionValueSet.has(value)) {
        const timeZone = (0, tzdb_1.getTimeZones)().find((tz) => tz.group.includes(value));
        if (timeZone)
            onChange(timeZone.name);
    }
}
exports.resolveValue = resolveValue;
function convertValidator(validator) {
    return (value) => {
        if (typeof value === 'number')
            throw new Error('Time zone validator received a number.');
        return validator(value);
    };
}
function convertAsyncValidator(validator) {
    return (value) => {
        if (typeof value === 'number')
            throw new Error('Time zone async validator received a number.');
        return validator(value);
    };
}
/**
 * A time zone dropdown. The 4 common US time zones are shown first, followed by every
 * other time zone. It uses the `@vvo/tzdb` time zone database.
 */
function TimeZoneInput({ id, name, placeholder, formControlSize, isClearable, width, validators, showValidation, enabled = true, asyncValidator, onAsyncError, onValidChange, validationKey, ...props }) {
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: props.value,
        onChange: props.onChange,
        defaultValue: props.defaultValue,
        fallbackValue: null,
    });
    const onChangeRef = (0, react_1.useRef)(onChange);
    (0, react_1.useEffect)(() => {
        onChangeRef.current = onChange;
    });
    (0, react_1.useEffect)(() => {
        resolveValue(value, onChangeRef.current);
    }, [value]);
    return ((0, jsx_runtime_1.jsx)(select_1.ValidatedSelect, { id: id, name: name, options: options, validators: validators.map(convertValidator), asyncValidator: asyncValidator ? convertAsyncValidator(asyncValidator) : undefined, onAsyncError: onAsyncError, value: value, onChange: onChange, showValidation: showValidation, placeholder: placeholder, formControlSize: formControlSize, width: width, isClearable: isClearable, enabled: enabled, onValidChange: onValidChange, validationKey: validationKey, formLevelValidatorOutput: props.formLevelValidatorOutput }, void 0));
}
exports.TimeZoneInput = TimeZoneInput;
function required() {
    return (value) => {
        if (value === null)
            return iti_react_core_1.Validators.required()('');
        return undefined;
    };
}
exports.TimeZoneValidators = {
    required,
};
