"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.postalCodeValidator = exports.isPostalCodeValid = exports.defaultPostalCodeValidationOptions = void 0;
exports.defaultPostalCodeValidationOptions = {
    allowCanadian: true,
};
/**
 * Determines if a postal code is valid. US 5-digit, US 9-digit, and Canadian postal
 * codes are supported.
 */
function isPostalCodeValid(code, options = exports.defaultPostalCodeValidationOptions) {
    code = code.replace('-', '').replace(' ', '');
    if (code.length === 5 || code.length === 9) {
        // US zip codes - valid if digits only
        return /^\d*$/.test(code);
    }
    if (code.length === 6 && options.allowCanadian) {
        // Canadian postal codes, e.g. A1A 1A1
        return /^(?:[a-z]\d){3}$/i.test(code);
    }
    return false;
}
exports.isPostalCodeValid = isPostalCodeValid;
/**
 * Validator for a postal code input. Uses [[`isPostalCodeValid`]].
 */
function postalCodeValidator(options = exports.defaultPostalCodeValidationOptions) {
    return (value) => {
        if (!value)
            return undefined;
        if (!isPostalCodeValid(value, options))
            return `Invalid ${options.allowCanadian ? 'postal' : 'zip'} code.`;
        return undefined;
    };
}
exports.postalCodeValidator = postalCodeValidator;
