"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DateInputNoPicker = exports.DateInputNoPickerValidators = exports.parseDateInputNoPickerValue = exports.formatDateInputNoPickerValue = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = __importStar(require("react"));
const moment_timezone_1 = __importDefault(require("moment-timezone"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../../validation");
const dateInputUtil_1 = require("./dateInputUtil");
/**
 * Get the initial value for a [[`DateInputNoPicker`]] component.
 *
 * @param timeZone an IANA time zone or `'local'`, which will use `moment.tz.guess()` as
 * the time zone.
 * @returns a formatted date string or `''` if the input moment was invalid
 */
function formatDateInputNoPickerValue(m, options) {
    if (!(m && m.isValid()))
        return '';
    if (!options.includesTime)
        return moment_timezone_1.default.utc(m).format(dateInputUtil_1.dateInputFormat);
    const timeZone = (0, dateInputUtil_1.getTimeZone)(options.timeZone);
    return (0, moment_timezone_1.default)(m).tz(timeZone).format(dateInputUtil_1.dateTimeInputFormat);
}
exports.formatDateInputNoPickerValue = formatDateInputNoPickerValue;
function parseValueCore(value, options) {
    // strict = true. Otherwise strings like "5" are considered valid.
    if (!options.includesTime)
        return moment_timezone_1.default.utc(value.trim(), dateInputUtil_1.dateInputFormat, true).startOf('day');
    const timeZone = (0, dateInputUtil_1.getTimeZone)(options.timeZone);
    return moment_timezone_1.default.tz(value.trim(), dateInputUtil_1.dateTimeInputFormat, true, timeZone);
}
/**
 * Parse the `value` of a [[`DateInputNoPicker`]] component.
 *
 * @param timeZone an IANA time zone or `'local'`, which will use `moment.tz.guess()` as
 * the time zone.
 * @returns a Moment object or undefined if the `value` was invalid
 */
function parseDateInputNoPickerValue(value, options) {
    if (typeof value !== 'string')
        return undefined;
    const d = parseValueCore(value, options);
    return d.isValid() ? d : undefined;
}
exports.parseDateInputNoPickerValue = parseDateInputNoPickerValue;
//
// Validators
//
function isValid(value, includesTime) {
    return parseValueCore(value, { includesTime, timeZone: 'Etc/UTC' }).isValid();
}
function formatValidator(includesTime) {
    return (value) => {
        if (value && !isValid(value, includesTime))
            return (0, dateInputUtil_1.getInvalidFeedback)(includesTime);
        return undefined;
    };
}
function required(options) {
    return (value) => {
        if (!value)
            return (0, dateInputUtil_1.getInvalidFeedback)(options.includesTime);
        return undefined;
    };
}
/** Validators for use with `DateInputNoPicker`. */
exports.DateInputNoPickerValidators = {
    required,
};
/**
 * A datetime input without a datepicker popover. Its value is just a `string`.
 * Good for things like date of birth. See also [[`DateInput`]].
 *
 * Use [[`formatDateInputNoPickerValue`]] to get the initial value for this input.
 *
 * Use [[`parseDateInputNoPickerValue`]] to get a `moment`
 * object from the string.
 */
exports.DateInputNoPicker = react_1.default.memo(({ placeholder, includesTime = false, enabled = true, readOnly = false, showValidation, name, ...otherProps }) => {
    var _a;
    const idGuidRef = (0, react_1.useRef)((0, iti_react_core_1.getGuid)());
    const id = (_a = otherProps.id) !== null && _a !== void 0 ? _a : idGuidRef.current;
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: otherProps.value,
        onChange: otherProps.onChange,
        defaultValue: otherProps.defaultValue,
        fallbackValue: '',
    });
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: otherProps.onValidChange,
        validators: [formatValidator(includesTime), ...otherProps.validators],
        validationKey: otherProps.validationKey,
        asyncValidator: otherProps.asyncValidator,
        onAsyncError: otherProps.onAsyncError,
        formLevelValidatorOutput: otherProps.formLevelValidatorOutput,
    });
    const classes = [
        'form-control',
        (0, validation_1.getValidationClass)(!validatorOutput, showValidation),
    ];
    if (otherProps.className)
        classes.push(otherProps.className);
    const className = classes.join(' ');
    return ((0, jsx_runtime_1.jsx)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation, children: (0, jsx_runtime_1.jsx)("input", { id: id, name: name, value: value, onChange: (e) => onChange(e.target.value), className: className, placeholder: placeholder, disabled: !enabled, readOnly: readOnly, autoComplete: "off" }, void 0) }, void 0));
});
