"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RadioValidators = exports.RadioInput = void 0;
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = __importDefault(require("react"));
const iti_react_core_1 = require("@interface-technologies/iti-react-core");
const validation_1 = require("../../validation");
const RadioButton_1 = require("./RadioButton");
const classSeparator = '__';
/**
 * Radio button input. It renders a group of radio buttons based on the `options` you
 * pass in.
 *
 * You can customize the style of both the container and the individual radio buttons
 * / labels. Use the devtools element inspector to see the class names you need to
 * target.
 */
exports.RadioInput = react_1.default.memo(({ options, enabled = true, showValidation, name, ...props }) => {
    const { value, onChange } = (0, iti_react_core_1.useControlledValue)({
        value: props.value,
        onChange: props.onChange,
        defaultValue: props.defaultValue,
        fallbackValue: null,
    });
    const validatorOutput = (0, iti_react_core_1.useValidation)({
        value,
        name,
        onValidChange: props.onValidChange,
        validators: props.validators,
        validationKey: props.validationKey,
        asyncValidator: props.asyncValidator,
        onAsyncError: props.onAsyncError,
        formLevelValidatorOutput: props.formLevelValidatorOutput,
    });
    const buttonOptions = {
        inline: true,
        ...props.buttonOptions,
    };
    const containerClass = 'radio-button-container';
    const containerClasses = [containerClass, name + classSeparator + containerClass];
    return ((0, jsx_runtime_1.jsx)(validation_1.ValidationFeedback, { validatorOutput: validatorOutput, showValidation: showValidation, children: (0, jsx_runtime_1.jsx)("div", { className: containerClasses.join(' '), children: options.map((o) => ((0, jsx_runtime_1.jsx)(RadioButton_1.RadioButton, { radioOption: o, name: name, value: value, onChange: onChange, enabled: enabled, inline: buttonOptions.inline }, o.value))) }, void 0) }, void 0));
});
function required() {
    return (value) => {
        if (value === null)
            return iti_react_core_1.Validators.required()('');
        return undefined;
    };
}
exports.RadioValidators = {
    required,
};
