"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterOption = exports.getNonGroupOptions = void 0;
const react_select_1 = require("react-select");
const lodash_1 = require("lodash");
/**
 * Takes in a list of normal [[`SelectOption`]]s and "group" select options
 * and flattens it out into a list of normal [[`SelectOption`]]s.
 */
function getNonGroupOptions(options) {
    const [groupOptions, nonGroupOptions] = (0, lodash_1.partition)(options, (o) => typeof o.value === 'undefined');
    return [
        ...nonGroupOptions,
        ...(0, lodash_1.flatten)(groupOptions.map((go) => go.options)),
    ];
}
exports.getNonGroupOptions = getNonGroupOptions;
/**
 * @internal
 *
 * Makes it so typing in one of our select components filters the options by the `label`
 * only, not the `label` and the `value` which is the default behavior.
 *
 * See https://react-select.com/advanced#custom-filter-logic.
 */
exports.filterOption = (0, react_select_1.createFilter)({
    stringify: (o) => o.label,
});
